*** FINITE SAMPLE DISTRIBUTION OF TEST STATISTICS UNDER NORMAL ERRORS

clear all
set seed 123
cd "/Users/Connor/Desktop/School/Michigan 2015/452/Lessons/Asymptotics : Unbiasedness : Consistency/"
gen info=.
save normaldistribution.dta, replace

*** DEFINING PROGRAM TO COMPUTE TEST STATISTICS WITH NORMAL ERRORS
program define betahat2
clear
args q
* OBSERVATION NUMBER q
set obs `q'
* DEFINING THE DGP
gen x = rnormal(1,1)
gen epsilon1= rnormal(0,1) 
gen y = 2*x+1+epsilon
reg y x
matrix b = e(b)
scalar b1 = b[1,1]
scalar b2 = b[1,2]
matrix V = e(V)
scalar seb1`i' = V[1,1]^.5
scalar bnorm= (b1-2)/seb1`i' 
end


*** RUNNING SIMULATIONS OVER DIFFERENT SAMPLE SIZES TO GENERATE A SET OF TEST STATISTICS
foreach i of numlist 5(2)11 20 30 40 100 200 {
simulate bnorm=bnorm b1=b1, reps(5000): betahat2 `i'
gen observations=`i'
append using normaldistribution.dta
save normaldistribution.dta, replace
}

*** FITTING KERNEL DENSITIES FOR TEST STATISTICS AND SAVING KERNEL DENSITIES FOR X AND Y
foreach i of numlist 5 7 9 11 20 30 40 100 200 {
kdensity bnorm if observation==`i', generate(x`i' y`i')
}

*** RESHAPING DATASET TO BE LONG
keep x* y* 
drop if x9=.
gen number=_n

reshape long x y, i(number) j(observations)

*** LABELING DATA AND GENERATING t-DENSITIES
gen tden=.
gen numobs=""
foreach i of numlist 5 7 9 11 20 30 40 100 200 {
replace numobs="`i' Observations" if observations==`i'
replace tden=tden(`i'-2,x) if observations==`i'
}

*** GRAPHING RESULTS
label var tden "t distribution with n-2 DOF"
label var y "Density of Test Statistics (Beta 1)"

label define test 5 "5 Observations" 7 "7 Observations" 9 "9 Observations" 11 "11 Observations" 20 "20 Observations" 30 "30 Observations" 40 "40 Observations" 100 "100 Observations" 200 "200 Observations"
label values observations test
save "distributionofteststatnorm.dta", replace

twoway line y x || line tden x, by(observations, rescale note(""))  xtitle("") scheme(s1mono)
graph export teststatisticsnormalerror.eps, replace




**** DEMONSTRATING ASYMPTOTIC RESULTS OF OLS UNDER NON-NORMAL ERRORS
** DISPLAING DISTRIBUTION OF ERROR TERMS 
clear all
set obs 10000000
gen epsilon1= rnormal(0,1) 
gen epsilon2= rgamma(5,2) 
gen unif=runiform()
gen epsilon = epsilon1 if unif<.3
replace epsilon = epsilon2 if unif>=.3
cd "/Users/Connor/Desktop/School/Michigan 2015/452/Lessons/Asymptotics : Unbiasedness : Consistency/"
kdensity epsilon, title("") scheme(s1mono)
graph export errortermdistribution.eps, replace

**** DEFINING PROGRAM TO SHOW ASYMPTOTIC BEHAVIOR OF TEST STATISTICS
clear all
set seed 123
cd "/Users/Connor/Desktop/School/Michigan 2015/452/Lessons/Asymptotics : Unbiasedness : Consistency/"
gen info=.
save nonnormaldistribution.dta, replace

program define betahat1
clear
args q
* OBSERVATION NUMBER'q'
set obs `q'
* DEFINING THE DGP
gen x = rnormal(1,1)
gen epsilon1= rnormal(0,1) 
gen epsilon2= rgamma(5,2)  
gen unif=runiform()
gen epsilon = epsilon1 if unif<.3
replace epsilon = epsilon2 if unif>=.3
gen y = 2*x+1+epsilon
reg y x
matrix b = e(b)
scalar b1 = b[1,1]
scalar b2 = b[1,2]
matrix V = e(V)
scalar seb1`i' = V[1,1]^.5
scalar bnorm= (b1-2)/seb1`i' 
end

* RUNNING PROGRAM OVER DIFFERENT SAMPLE SIZES TO GENERATE DISTRIBUTION OF STATISTICS
foreach i of numlist 5(2)11 20 30 40 100 200
simulate bnorm=bnorm b1=b1, reps(5000): betahat1 `i'
gen observations=`i'
append using normaldistribution.dta
save nonnormaldistribution.dta, replace
}

* KERNEL DENSITY OF TEST STATISTICS
foreach i of numlist 5 7 9 11 20 30 40 100 200 {
kdensity bnorm if observation==`i', generate(x`i' y`i')
}

* RESHAPING DATA
keep x* y* 
drop if x9==.
gen number=_n
reshape long x y, i(number) j(observations)

gen numobs=""
foreach i of numlist 5 7 9 11 20 30 40 100 200 {
replace numobs="`i' Observations" if observations==`i'
}
gen normal=normalden(x)

* GRAPHING DATA
label var normal "Normal Density"
label var y "Density of Test Statistics (Beta 1)"
label define test 5 "5 Observations" 7 "7 Observations" 9 "9 Observations" 11 "11 Observations" 20 "20 Observations" 30 "30 Observations" 40 "40 Observations" 100 "100 Observations" 200 "200 Observations"
label values observations test
save "distributionofteststat.dta", replace
twoway line y x || line normal x if inrange(x,-2,2), by(observations, rescale note(""))  xtitle("") scheme(s1mono)
graph export betahatdist.eps, replace
