**** PROGRAM TO SHOW UNBIASEDNESS OF BETA HAT IN OLS
clear all
set seed 12345
set more off
cd "/Users/Connor/Desktop/School/Michigan 2015/452/Lessons/Asymptotics : Unbiasedness : Consistency/"

program define betahatunbiased
clear
args q
* VARIES BY SAMPLE SIZE 'q'
set obs `q'
* DEFINING DGP
gen x = rnormal(1,1)
gen epsilon= rnormal()
gen y = 2*x+1+epsilon
reg y x
matrix b = e(b)
scalar b1 = b[1,1]
scalar b2 = b[1,2]
scalar b1bias = b[1,1]+1/(`q')^.5
matrix V = e(V)
scalar seb1 = V[1,1]^.5
scalar seb2 = V[2,2]^.5
summarize x
scalar setrue1= (1/((`q'-1)*r(sd)^2))^.5
end

*** SIMULATION WITH FOR LOOP TO SHOW 'UNBIASEDNESS' OVER REPEATED SAMPLES FROM DATASETS OF VARYING SIZE
*** AVERAGES COMPUTED OVER ALL BETA HATS
forvalues i=5(1)100 {
simulate bhat1=b1 bhat2=b2 sehat1=seb1 setrue1=setrue1 b1bias=b1bias, reps(1000): betahatunbiased `i'
summarize bhat1
scalar b1hat`i'=r(mean)
summarize bhat2
scalar b2hat`i'=r(mean)
summarize sehat1
scalar se1hat`i'=r(mean)
summarize setrue1
scalar se1true`i'=r(mean)
summarize b1bias
scalar b1bias`i'=r(mean)
}

*** FILLING DATASET WITH RELEVANT VALUES
clear
set obs 1000
gen b1hat=.
gen b1true=2
gen b2true=1
gen se1hat=.
gen se1true=.
gen b1bias=.
gen nvals=_n
gen b2hat=.

forvalues i=5(1)100 {
replace b1hat= b1hat`i' if nvals==`i'
replace b2hat= b2hat`i' if nvals==`i'
replace se1hat= se1hat`i' if nvals==`i'
replace se1true= se1true`i' if nvals==`i'
replace b1bias= b1bias`i' if nvals==`i'
}

drop if b1hat==.

label var nvals "Number of Observations"
label var b1hat "Beta 1 (Hat)"
label var b1true "Beta 1 (True)"
label var b2hat "Beta 0 (Hat)"
label var b2true "Beta 0 (True)"
label var se1hat "SE Beta 1"
label var se1true "SD Beta 1"
label var b1bias "Beta 1 (Hat) + 1/sqrt(N)"
save "unbiaseddata.dta", replace

** GRAPHING RESULTS
twoway line se1hat se1true nvals, ylabel(0(.1).8) scheme(s1mono) ytitle("Value of SE / SD")
graph export se1biased.eps, replace
twoway line b1hat b1true nvals, ylabel(0(.5)2.5) scheme(s1mono) ytitle("Value of Beta")
graph export b1unbiased.eps, replace
twoway line b2hat b2true nvals, ylabel(0(.5)2.5) scheme(s1mono) ytitle("Value of Beta")
graph export b2unbiased.eps, replace
twoway line b1bias b1true nvals, ylabel(0(.5)2.5) scheme(s1mono) ytitle("Value of Beta")
graph export b1biased.eps, replace


***** PROGRAM TO SHOW CONSISTENCY OF BETA HAT IN OLS
clear all
cd "/Users/Connor/Desktop/School/Michigan 2015/452/Lessons/Asymptotics : Unbiasedness : Consistency/"
quietly forvalues i=5/2000 {
clear
set seed 123
* SETTING NUMBER OF OBSERVATIONS `i'
set obs `i'
* DEFINING DGP
gen x = rnormal(1,1)
gen epsilon= rnormal()
gen y = 2*x+1+epsilon
reg y x
matrix b = e(b)
* SAVING ESTIMATED COVARIATES OVER SAMPLE SIZE `i'
scalar b1`i' = b[1,1]
scalar b2`i' = b[1,2]
matrix V = e(V)
scalar seb1`i' = V[1,1]^.5
scalar seb2`i' = V[2,2]^.5
scalar b1bias = b[1,1]+1/(`i')^.5
summarize x
scalar setrue1`i'= (1/((`i'-1)*r(sd)^2))^.5
}

clear

** FILLING DATASETS WITH RELEVANT COEFFICIENTS
set obs 2000
gen b1=.
gen b2=.
gen seb1=.
gen setrue1=.
gen seb2=.
gen b1bias=.
gen nvals=_n

quietly forvalues i=5/500 {
replace b1=b1`i' if nvals==`i'
replace b2=b2`i' if nvals==`i'
replace seb1=seb1`i' if nvals==`i'
replace setrue1=setrue1`i' if nvals==`i'
replace seb2=seb2`i' if nvals==`i'
replace b1bias= b1bias`i' if nvals==`i'
}

gen b1true=2
gen b2true=1

** GRAPHING RESULTS
label var nvals "Number of Observations"
label var b1 "Beta 1 (Hat)"
label var b1true "Beta 1 (True)"
label var b2 "Beta 0 (Hat)"
label var b2true "Beta 0 (True)"
label var seb1 "SE Beta 1"
label var setrue1 "SD Beta 1"
label var b1bias "Beta 1 (Hat) + 1/sqrt(N)"

save "consistency.dta", replace

twoway line seb1 setrue1 nvals, ylabel(0(.1).5) scheme(s1mono) ytitle("Value of SE / SD")
graph export se1biased.eps, replace
twoway line b1 btrue nvals, ylabel(0(.5)2.5) ytitle("Value of Beta")
graph export  b1consistent.eps, replace
twoway line b1bias btrue nvals, ylabel(0(.5)2.5) ytitle("Value of Beta")
graph export  b1biasconsistent.eps.eps, replace

