****** SECTION 14: STATA PRACTICE (14)

***** FGLS - LPM

**** GENERATE A NEW VARIABLE MEASURING WHETHER OR NOT AN INDIVIDUAL IS A COLLEGE GRADUATE
generate collegegrade=.
replace collegegrade=1 if highestdegree>=4
replace collegegrade=0 if highestdegree<4

**** REGRESS THE VARIABLE MEASURING COLLEGE GRADUATION ON THE SAME CONTROLS AS BEFORE
regress collegegrade highestgrade_mother asvabmathverbal_1999

**** PREDICT EXPECTED PROBABILITIES 
predict predictedprob, xb

**** ESTIMATE THE VARIANCE OF THE ERROR TERM 
generate variance=predictedprob*(1-predictedprob)

**** RUN WEIGHTED LEAST SQUARES
generate inversevariance=1/variance

**** REDERIVE THE WEIGHTED LEAST SQUARES RESULTS
regress collegegrade highestgrade_mother asvabmathverbal_1999 [aw=inversevariance]

foreach v of varlist collegegrade highestgrade_mother asvabmathverbal_1999 {
generate `v'weighted=`v'*inversevariance^.5
}
gen constantweighted=1*inversevariance^.5
regress collegegradeweighted highestgrade_motherweighted asvabmathverbal_1999weighted constantweighted, noconst
regress collegegrade highestgrade_mother asvabmathverbal_1999 [aw=inversevariance]


***** FGLS - REGRESSION

**** REGRESS HIGHESTGRADE ON HIGHESTGRADE MOTHER, ASVAB
regress highestgrade highestgrade_mother asvabmathverbal_1999

**** PREDICT THE RESIDUALS FROM THIS REGRESSION, SQUARE THEM AND TAKE A LOG
predict highgraderesid, resid
generate lnhighgraderesidsq=log(highgraderesid^2)

**** ESTIMATE THE STRUCUTRAL RELATIONSHIP BETWEEN THE LOG OF THE SQUARED RESIDAULS AND HIGHESTGRADE MOTHER, ASVAB
regress lnhighgraderesidsq highestgrade_mother asvabmathverbal_1999

**** GENERATE AN ESTIMATE OF THE VARIANCE OF THE ERROR TERM
predict predictedlnsq, xb
generate variance=exp(predictedlnsq)
generate inversevariance2=1/variance

regress highestgrade highestgrade_mother asvabmathverbal_1999
regress highestgrade highestgrade_mother asvabmathverbal_1999 [aw=inversevariance2]


***** RAMSEY TEST

**** RUN A RAMSEY TEST WHERE WE REGRESS HIGHESTGRADE ON HIGHESTGRADE_MOTHER, ASVAB
regress highestgrade highestgrade_mother asvabmathverbal_1999

**** GENERATE THE 2,3 and 4TH POWERS OF THE PREDICTED VALUES
predict gradehat1, xb
generate gradehat2=gradehat1^2
generate gradehat3=gradehat1^3
generate gradehat4=gradehat1^4

**** IMPLEMENT THE RAMSEY TEST WITH THE 2ND AND 3RD POWERS (USE THIS ON THE HOMEWORK)
regress highestgrade highestgrade_mother asvabmathverbal_1999 gradehat2 gradehat3 
test (gradehat2=0) (gradehat3=0) 

**** IMPLEMENT THE RAMSEY TEST WITH THE 2ND, 3RD AND 4TH POWERS
regress highestgrade highestgrade_mother asvabmathverbal_1999 gradehat2 gradehat3 
test (gradehat2=0) (gradehat3=0) 

**** USE THE OVTEST
regress highestgrade highestgrade_mother asvabmathverbal_1999
estat ovtest


***** DAVIDSON-MCKINNEN

**** RUN A D-M TEST WITH HIGHESTGRADE REGRESSED ON HIGHESTGRADE_MOTHER, ASVAB AS MODEL 1 AND HIGHESTGRADE REGRESSED ON HIGHESTGRADE_MOTHER
**** ON LOG OF ASVAB AS MODEL2

**** ESTIMATE MODEL1 AND GENERATE PREDICTED VALUES
regress highestgrade highestgrade_mother asvabmathverbal_1999
predict predmodel1, xb

**** ESTIMATE MODEL2 AND GENERATE PREDICTED VALUES
generate logasvab=log(asvabmathverbal)
regress highestgrade highestgrade_mother logasvab
predict predmodel2, xb

**** TEST THE MODELS BY INCLUDING PREDICTED VALUES FROM MODEL 2
regress highestgrade highestgrade_mother asvabmathverbal_1999 predmodel2
test (predmodel2=0)

regress highestgrade highestgrade_mother logasvab predmodel1
test (predmodel1=0)


***** MEASUREMENT ERROR
**** GENERATE A NEW PRETAXLABORINCOME VARIABLE WITH RANDOM NORMAL ERROR, MEAN 0 SD 30000
set seed 12345
generate pretaxlaborerror = pretaxlaborincome+rnormal(0, 30000)
sum pretaxlabor*
reg pretaxlaborincome highestgrade asvab
reg pretaxlaborerror highestgrade asvab

**** GENERATE A NEW ASVAB SCORE WITH RANDOM NORMAL ERROR MEAN 0 SD 10000
generate error = rnormal(0, 10000)
generate asvaberror = error + asvab
sum error

**** REGRESS PRETAXLABORINCOME ON HIGHEST GRADE AND THE 'TRUE' ASVAB SCORE
reg pretaxlaborincome highestgrade asvabmathverbal

**** REGRESS PRETAXLABORINCOME ON HIGHEST GRADE AND THE 'ERROR' ASVAB SCORE
reg pretaxlaborincome highestgrade asvaberror

**** COMPARE THE TWO COEFFICIENTS USING THE FORMULAS FOR ATTENUATION BIAS
regress asvabmathverbal highestgrade
predict asvabpredresid, resid
sum asvabpredresid

sum asvabmathverbal
disp (23800.7^2)/(23800.7^2+10010.73 ^2)*.1996305 



******* OPTIONAL
***** DEMONSTRATE HOW WEGHTING BY THE NUMBER OF OBSERVATIONS WORKS 

***** DROP IRRELEVANT OBSERVATIONS
foreach v of varlist pretaxlaborincome asvabmathverbal_1999 delinquency highestgrade highestgrade_mother highestgrade_father {
drop if `v'==.
}

***** GENERATE COUNTS OF OBSERVATIONS PER SUBGROUP (SUBGROUPS CREATED BY HIGHESTGRADE_M AND HIGHESTGRADE_F)
bys highestgrade_mother highestgrade_father: generate observations=_N

***** ESTIMATE OVERALL REGRESSION OF PRETAXLABOR ON ASVAB, DELINQUNE, HIGHESTGRADE, HIGHESTGRADE_M AND HIGHESTGRADE_F
regress pretaxlaborincome asvabmathverbal_1999 delinquency  highestgrade highestgrade_mother highestgrade_father

***** COLLAPSE OBSERVATIONS INTO AN AVERAGE AND RECOMPUTE THE PREVIOUS REGRESSION USING THE APPROPRIATE WEIGHTS
collapse (mean) pretaxlaborincome asvabmathverbal_1999 delinquency  highestgrade, by(highestgrade_mother highestgrade_father observations)
regress pretaxlaborincome asvabmathverbal_1999 delinquency highestgrade highestgrade_mother highestgrade_father [aw=observations]
regress pretaxlaborincome asvabmathverbal_1999 delinquency highestgrade highestgrade_mother highestgrade_father


