*** UNBIASEDNESS OF BETA HAT
clear all
set seed 12345

program define betahatunbiased
clear
args q
set obs `q'
gen x = rnormal(1,1)
gen epsilon= rnormal()
gen y = 2*x+1+epsilon
reg y x
matrix b = e(b)
scalar b1 = b[1,1]
scalar b2 = b[1,2]
matrix V = e(V)
scalar seb1 = V[1,1]^.5
scalar seb2 = V[2,2]^.5
summarize x
scalar setrue1= (1/((`q'-1)*r(sd)^2))^.5
end

forvalues i=5(2)51 {
simulate bhat1=b1 bhat2=b2 sehat1=seb1 setrue1=setrue1, reps(500): betahatunbiased `i'
summarize bhat1
scalar b1hat`i'=r(mean)
summarize bhat2
scalar b2hat`i'=r(mean)
summarize sehat1
scalar se1hat`i'=r(mean)
summarize setrue1
scalar se1true`i'=r(mean)
}

clear
set obs 1000
gen b1hat=.
gen b1true=2
gen se1hat=.
gen se1true=.

gen nvals=_n

forvalues i=5(2)51 {
replace b1hat= b1hat`i' if nvals==`i'
replace se1hat= se1hat`i' if nvals==`i'
replace se1true= se1true`i' if nvals==`i'
}

drop if b1hat==.

twoway line se1hat se1true nvals, ylabel(0(.1).8)
twoway line b1hat b1true nvals, ylabel(1.6(.1)2.6)



****
clear all
quietly forvalues i=5/500 {
clear
set seed 123
*set obs `i'
set obs `i'
gen x = rnormal(1,1)
gen epsilon= rnormal()
gen y = 2*x+1+epsilon
reg y x
matrix b = e(b)
scalar b1`i' = b[1,1]
scalar b2`i' = b[1,2]
matrix V = e(V)
scalar seb1`i' = V[1,1]^.5
scalar seb2`i' = V[2,2]^.5
summarize x
scalar setrue1`i'= (1/((`i'-1)*r(sd)^2))^.5
}

clear

set obs 500
gen b1=.
gen b2=.
gen seb1=.
gen setrue1=.
gen seb2=.

gen nvals=_n

quietly forvalues i=5/500 {
replace b1=b1`i' if nvals==`i'
replace b2=b2`i' if nvals==`i'
replace seb1=seb1`i' if nvals==`i'
replace setrue1=setrue1`i' if nvals==`i'
replace seb2=seb2`i' if nvals==`i'
}

gen btrue=2
twoway line seb1 setrue1 nvals, ylabel(0(.1).5)

twoway line b1 btrue nvals, ylabel(0(.1).5)

clear all
set obs 10000000
gen epsilon1= rnormal(0,1) 
gen epsilon2= rgamma(5,2) 
gen unif=runiform()
gen epsilon = epsilon1 if unif<.3
replace epsilon = epsilon2 if unif>=.3
cd "/Users/Connor/Desktop/School/Michigan 2015/452/Lessons/Section 6"
kdensity epsilon, title("") scheme(s1mono)
graph export errortermdistribution.eps, replace




*** NORMAL DISTRIBUTION
clear all
set seed 123
cd "/Users/Connor/Desktop/School/Michigan 2015/452/Lessons/Section 4"
gen info=.
save normaldistribution.dta, replace


program define betahatunbiased1
clear
args q
set obs `q'
gen x = rnormal(1,1)
gen epsilon1= rnormal(0,1) 
gen epsilon2= rgamma(5,2)  
gen unif=runiform()
gen epsilon = epsilon1 if unif<.3
replace epsilon = epsilon2 if unif>=.3
gen y = 2*x+1+epsilon
reg y x
matrix b = e(b)
scalar b1 = b[1,1]
scalar b2 = b[1,2]
matrix V = e(V)
scalar seb1`i' = V[1,1]^.5
scalar bnorm= (b1-2)/seb1`i' 
end



forvalues i=5(2)11 {
simulate bnorm=bnorm b1=b1, reps(500): betahatunbiased1 `i'
gen observations=`i'
append using normaldistribution.dta
save normaldistribution.dta, replace
}

clear
simulate bnorm=bnorm b1=b1, reps(500): betahatunbiased1 20
gen observations=20
append using normaldistribution.dta
save normaldistribution.dta, replace

clear
simulate bnorm=bnorm b1=b1, reps(500): betahatunbiased1 30
gen observations=30
append using normaldistribution.dta
save normaldistribution.dta, replace

simulate bnorm=bnorm b1=b1, reps(500): betahatunbiased1 40
gen observations=40
append using normaldistribution.dta
save normaldistribution.dta, replace

simulate bnorm=bnorm b1=b1, reps(500): betahatunbiased1 100
gen observations=100
append using normaldistribution.dta
save normaldistribution.dta, replace

simulate bnorm=bnorm b1=b1, reps(500): betahatunbiased1 200
gen observations=200
append using normaldistribution.dta
save normaldistribution.dta, replace



foreach i of numlist 5 7 9 11 20 30 40 100 200 {
kdensity bnorm if observation==`i', generate(x`i' y`i')
}

keep x* y* 
drop if x9==.

gen number=_n

reshape long x y, i(number) j(observations)

gen numobs=""
foreach i of numlist 5 7 9 11 20 30 40 100 200 {
replace numobs="`i' Observations" if observations==`i'
}
gen normal=normalden(x)

label var normal "Normal Density"
label var y "Density of Standardized Beta1 Hat Values"


label define test 5 "5 Observations" 7 "7 Observations" 9 "9 Observations" 11 "11 Observations" 20 "20 Observations" 30 "30 Observations" 40 "40 Observations" 100 "100 Observations" 200 "200 Observations"
label values observations test
cd "/Users/Connor/Desktop/School/Michigan 2015/452/Lessons/Section 6"
twoway line y x || line normal x, by(observations, rescale note(""))  xtitle("") scheme(s1mono)
graph export betahatdist.eps, replace




















